/* This script lets the user browse through the tracks and
 * adjust the volume with a remote control (that supports
 * RC5 codes). This example is described in detail in an
 * application note; it can be adapted to other protocols
 * that are commonly in use for remote controls.
 *
 * For this example to run, an IR-receiver chip must be
 * branched to I/O pin 11. See the application note for
 * details.
 */

#include rc5codes       /* code definitions */
#include rc5decode      /* the RC5 decoder routines */

new bool: UpdateDisplay

main()
    {
    /* set up I/O pin 11 for sampling RC5 codes */
    rc5_init 11

    /* set up a display for visual feedback */
    console 20, 4
    settimer 500
    }

rc5handler(code, repeat)
    {
    switch (code)
        {
        case RC5_ChannelUp:   nexttrack repeat
        case RC5_ChannelDown: prevtrack repeat
        case RC5_VolumeUp:    volumeup
        case RC5_VolumeDown:  volumedown
        }
    UpdateDisplay = true
    }

const NumTracks = 8
new CurrentTrack = 0

prevtrack(repeat)
    {
    if (!repeat)
        {
        if (--CurrentTrack < 0)
            CurrentTrack = NumTracks - 1
        playtrack
        }
    }

nexttrack(repeat)
    {
    if (!repeat)
        {
        if (++CurrentTrack >= NumTracks)
            CurrentTrack = 0
        playtrack
        }
    }

playtrack()
    {
    new name[] = !"track?.mp3"
    name{5} = CurrentTrack + '1'
    play name
    }

new CurrentVolume = 100

volumedown()
    {
    if (CurrentVolume > 0)
        setvolume --CurrentVolume
    }

volumeup()
    {
    if (CurrentVolume < 100)
        setvolume ++CurrentVolume
    }

@timer()
    {
    if (UpdateDisplay)
        {
        clrscr
        printf "track %d\nvolume %d", CurrentTrack, CurrentVolume
        UpdateDisplay = false
        }
    }
